@@ -24,7 +24,7 @@ checkInstalledHSVersion()
   # version of HS being installed has to be greater than the current HS version
   if [ -f ${HSMANIFEST} ]; then
       HSPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${HSMANIFEST})
-      HSCURRVERSION=5.1.11.388
+      HSCURRVERSION=5.1.13.177
 
       existing_ver="$(csc_vercmp "$HSPREVVERSION" "$HSCURRVERSION")"
       if [ "$existing_ver" != older ]; then
@@ -106,10 +106,10 @@ SYSVLEVELS="2 3 4 5"
 CURRENTDIR=`dirname $0 2> /dev/null`
 VPNMANIFEST="${CSC_INSTPREFIX}/ACManifestVPN.xml"
 
-LOGFNAME=`/bin/date "+posture-5.1.11.388-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=`/usr/bin/date "+posture-5.1.11.388-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=`date "+posture-5.1.11.388-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=posture-5.1.11.388-install.log
+LOGFNAME=`/bin/date "+posture-5.1.13.177-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=`/usr/bin/date "+posture-5.1.13.177-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=`date "+posture-5.1.13.177-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=posture-5.1.13.177-install.log
 
 DIR=`dirname $0 2> /dev/null` || 
   DIR=`/usr/bin/dirname $0 2> /dev/null` || 
@@ -150,7 +150,7 @@ do
 done
 
 echo "Installing Cisco Secure Client - Secure Firewall Posture..."
-echo "Installing Cisco Secure Client - Secure Firewall Posture v5.1.11.388..." > /tmp/${LOGFNAME}
+echo "Installing Cisco Secure Client - Secure Firewall Posture v5.1.13.177..." > /tmp/${LOGFNAME}
 echo `whoami` "invoked $0 from " `pwd` " at " `date` >> /tmp/${LOGFNAME}
 echo ""
 
@@ -160,8 +160,9 @@ if [ "x${ID}" != "x0" ]; then
   exitInstallation 1
 fi
 
+postureStandalone=false
 # Posture requires VPN to be installed. We check the presence of the vpn manifest file to check if it is installed.
-if [ ! -f ${VPNMANIFEST} ]; then
+if [ false = ${postureStandalone} ] && [ ! -f ${VPNMANIFEST} ]; then
     echo "AnyConnect VPN should be installed before Posture installation. Install Cisco Secure Client - AnyConnect VPN to proceed."
     echo "AnyConnect VPN should be installed before Posture installation. Install Cisco Secure Client - AnyConnect VPN to proceed." >> /tmp/${LOGFNAME}
     exitInstallation 1
@@ -179,12 +180,18 @@ if [ -f "${CURRENTDIR}/${POSTUREMANIFEST}" ] && [ -f ${VPNMANIFEST} ]; then
     fi
 fi
 
-if [ "$postureVersionMatchesVPN" = false ]; then
+if [ false = ${postureStandalone} ] && [ "$postureVersionMatchesVPN" = false ]; then
     echo "Please use posture installer from Cisco Secure Client package with version ${VPNVERSION} for the installation"
     echo "Please use posture installer from Cisco Secure Client package with version ${VPNVERSION} for the installation" >> /tmp/${LOGFNAME}
     exitInstallation 1
 fi
 
+# As we move the Posture plugin to the plugins directory, and if vpn is not installed
+# those directories are not created, so we create them here
+if [ true = ${postureStandalone} ]; then
+    mkdir -p ${CSC_INSTPREFIX}/bin/plugins
+fi
+
 if [ "x${ARG_NO_LICENSE}" = "x1" ]; then
 
     echo "Skipping license text ..."
@@ -364,26 +371,26 @@ chmod 755 ${BINDIR}/csd_uninstall.sh
 echo "done."
 
 # hostscan downgrade support related directory.
-HOSTSCAN_DOWNGRADE_SYMLINK="/opt/cisco/hostscan"
-HOSTSCAN_DOWNGRADE_DIR="/opt/cisco/anyconnect/securefirewallposture/ac_hostscan"
+HOSTSCAN_PKG_DOWNGRADE_SYMLINK="/opt/cisco/hostscan"
+HOSTSCAN_PKG_DOWNGRADE_DIR="/opt/cisco/secureclient/securefirewallposture/ac_hostscan"
 
 echo "Making provision for AnyConnect Hostscan..."
 echo "Making provision for AnyConnect Hostscan..." >> /tmp/${LOGFNAME}
 
-echo "Installing AnyConnect Hostscan directory ${HOSTSCAN_DOWNGRADE_DIR}" >> /tmp/${LOGFNAME}
-${INSTALL} -d ${HOSTSCAN_DOWNGRADE_DIR} || ( echo "failed." && exitInstallation 1 )
-# ${INSTALL} -o root -m 755 ${HOSTSCAN_DOWNGRADE_DIR} || ( echo "failed." && exitInstallation 1 )
-echo "Installing AnyConnect Hostscan bin directory ${HOSTSCAN_DOWNGRADE_DIR}/bin" >> /tmp/${LOGFNAME}
-${INSTALL} -d ${HOSTSCAN_DOWNGRADE_DIR}/bin || ( echo "failed." && exitInstallation 1 )
-echo "Installing AnyConnect Hostscan lib directory ${HOSTSCAN_DOWNGRADE_DIR}/lib" >> /tmp/${LOGFNAME}
-${INSTALL} -d ${HOSTSCAN_DOWNGRADE_DIR}/lib || ( echo "failed." && exitInstallation 1 )
-echo "Installing AnyConnect Hostscan log directory ${HOSTSCAN_DOWNGRADE_DIR}/log" >> /tmp/${LOGFNAME}
-${INSTALL} -d ${HOSTSCAN_DOWNGRADE_DIR}/log || ( echo "failed." && exitInstallation 1 )
+echo "Installing AnyConnect Hostscan directory ${HOSTSCAN_PKG_DOWNGRADE_DIR}" >> /tmp/${LOGFNAME}
+${INSTALL} -d ${HOSTSCAN_PKG_DOWNGRADE_DIR} || ( echo "failed." && exitInstallation 1 )
+# ${INSTALL} -o root -m 755 ${HOSTSCAN_PKG_DOWNGRADE_DIR} || ( echo "failed." && exitInstallation 1 )
+echo "Installing AnyConnect Hostscan bin directory ${HOSTSCAN_PKG_DOWNGRADE_DIR}/bin" >> /tmp/${LOGFNAME}
+${INSTALL} -d ${HOSTSCAN_PKG_DOWNGRADE_DIR}/bin || ( echo "failed." && exitInstallation 1 )
+echo "Installing AnyConnect Hostscan lib directory ${HOSTSCAN_PKG_DOWNGRADE_DIR}/lib" >> /tmp/${LOGFNAME}
+${INSTALL} -d ${HOSTSCAN_PKG_DOWNGRADE_DIR}/lib || ( echo "failed." && exitInstallation 1 )
+echo "Installing AnyConnect Hostscan log directory ${HOSTSCAN_PKG_DOWNGRADE_DIR}/log" >> /tmp/${LOGFNAME}
+${INSTALL} -d ${HOSTSCAN_PKG_DOWNGRADE_DIR}/log || ( echo "failed." && exitInstallation 1 )
 
-if [ ! -e ${HOSTSCAN_DOWNGRADE_SYMLINK} ]; then
+if [ ! -e ${HOSTSCAN_PKG_DOWNGRADE_SYMLINK} ]; then
   echo "Creating AnyConnect Hostscan symbolic link" >> /tmp/${LOGFNAME}
-  echo "ln -f -s ${HOSTSCAN_DOWNGRADE_DIR} ${HOSTSCAN_DOWNGRADE_SYMLINK}"  >> /tmp/${LOGFNAME}
-  ln -f -s ${HOSTSCAN_DOWNGRADE_DIR} ${HOSTSCAN_DOWNGRADE_SYMLINK} || ( echo "failed." && exitInstallation 1 )
+  echo "ln -f -s ${HOSTSCAN_PKG_DOWNGRADE_DIR} ${HOSTSCAN_PKG_DOWNGRADE_SYMLINK}"  >> /tmp/${LOGFNAME}
+  ln -f -s ${HOSTSCAN_PKG_DOWNGRADE_DIR} ${HOSTSCAN_PKG_DOWNGRADE_SYMLINK} || ( echo "failed." && exitInstallation 1 )
 fi
 
 echo "Done Making provision for AnyConnect Hostscan."
